@@ -1,19 +1,16 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Dist::Zilla::Plugin::Bootstrap::ShareDir::Module;
 
-our $VERSION = '1.001001';
+our $VERSION = '1.001002';
 
 # ABSTRACT: Use a share directory on your dist for a module during bootstrap
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Moose qw( with has around );
-use Dist::Zilla::Util::ConfigDumper qw( config_dumper );
-
 with 'Dist::Zilla::Role::Bootstrap';
 
 
@@ -37,7 +34,19 @@ has module_map => (
 
 sub _build_module_map { return {} }
 
-around 'dump_config' => config_dumper( __PACKAGE__, { attrs => [qw( module_map )] } );
+around 'dump_config' => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config = $self->$orig(@args);
+  my $localconf = $config->{ +__PACKAGE__ } = {};
+
+  if ( $self->meta->find_attribute_by_name('module_map')->has_value($self) ) {
+    $localconf->{module_map} = $self->module_map;
+  }
+  $localconf->{ q[$] . __PACKAGE__ . '::VERSION' } = $VERSION
+    unless __PACKAGE__ eq ref $self;
+
+  return $config;
+};
 
 around 'plugin_from_config' => sub {
   my ( $orig, $self, $name, $payload, $section ) = @_;
@@ -104,7 +113,7 @@ Dist::Zilla::Plugin::Bootstrap::ShareDir::Module - Use a share directory on your
 
 =head1 VERSION
 
-version 1.001001
+version 1.001002
 
 =head1 DESCRIPTION
 
@@ -167,7 +176,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
